@@ -1,7 +1,7 @@
 """Subscriber for the Smart Device Management event based API."""
-from abc import ABC, abstractmethod
 import asyncio
 import json
+from abc import ABC, abstractmethod
 
 from google.cloud import pubsub_v1
 
@@ -47,8 +47,10 @@ class GoogleNestSubscriber:
         self._api = GoogleNestAPI(auth, project_id)
         self._subscriber_factory = subscriber_factory
         self._future = None
-        self._device_manager_task = None
         self._callback = None
+        self._device_manager_task = asyncio.create_task(
+            self._async_create_device_manager()
+        )
 
     def set_update_callback(self, callback: EventCallback):
         """Register a callback invoked when new messages are received."""
@@ -60,9 +62,6 @@ class GoogleNestSubscriber:
         self._future = await self._subscriber_factory.new_subscriber(
             creds, self._subscriber_id, self._subscribe_callback
         )
-        self._device_manager_task = asyncio.create_task(
-            self._async_create_device_manager()
-        )
         return await self._device_manager_task
 
     def wait(self):
@@ -73,8 +72,7 @@ class GoogleNestSubscriber:
         """Tells the subscriber to start shutting down."""
         return self._future.cancel()
 
-    @property
-    async def async_device_manager(self) -> DeviceManager:
+    async def async_get_device_manager(self) -> DeviceManager:
         """Return the DeviceManger with the current state of devices."""
         return await self._device_manager_task
 
